@@ -14,10 +14,8 @@ Example:
     print(lazy_obj.name) # Makes API request here to get name
 """
 import os
-from datetime import timedelta
 from typing import Any, TypeVar, Union
 
-from dateutil.parser import parse
 from github import Consts, GithubIntegration, GithubRetry
 from github.Auth import AppAuth, AppUserAuth, Token
 from github.GithubObject import CompletableGithubObject
@@ -30,10 +28,9 @@ T = TypeVar("T")
 
 class LazyRequester(Requester):
     """
-    This class is a lazy version of Requester, which means that it will not make any requests to the API
+    This class is a lazy version of the Requester class. It does not make any requests to the API
     until the object is accessed.
-    When any attribute of Requester is accessed, initialize the requester.
-
+    When any attribute of Requester is accessed, the requester is initialized.
     """
 
     # noinspection PyMissingConstructor
@@ -62,15 +59,10 @@ class LazyRequester(Requester):
 
         """
         if os.environ.get("CLIENT_ID"):
-            # date = parse(os.environ.get("DATE"))
-            #
             auth = AppUserAuth(
                 client_id=os.environ.get("CLIENT_ID"),
                 client_secret=os.environ.get("CLIENT_SECRET"),
                 token=os.environ.get("TOKEN"),
-            #     expires_at=date + timedelta(seconds=28800),
-            #     refresh_token=os.environ.get("REFRESH_TOKEN"),
-            #     refresh_expires_at=date + timedelta(seconds=15811200),
             )
 
         else:
@@ -112,8 +104,11 @@ class LazyCompletableGithubObject(CompletableGithubObject):
         attributes: dict[str, Any] = None,
         completed: bool = False,
     ) -> None:
-        if attributes.get("url", "").startswith("https://github"):
-            attributes["url"] = attributes["url"].replace("https://github.com", "https://api.github.com/repos")
+        # if attributes.get("url", "").startswith("https://github"):
+        #     attributes["url"] = attributes["url"].replace("https://github.com", "https://api.github.com/repos")
+        #     attributes["url"] = attributes["url"].replace("/commit/", "/commits/")
+        # if isinstance(self, GitCommit):
+        #     attributes["sha"] = attributes["id"]
         # noinspection PyTypeChecker
         CompletableGithubObject.__init__(
             self,
